/*****************************************************************************\
     Snes9x - Portable Super Nintendo Entertainment System (TM) emulator.
                This file is licensed under the Snes9x License.
   For further information, consult the LICENSE file in the root directory.
\*****************************************************************************/

#ifndef _filter_xbrz_h_
#define _filter_xbrz_h_

void filter_2xBRZ (uint8 *, int, uint8 *, int, int, int);
void filter_3xBRZ (uint8 *, int, uint8 *, int, int, int);
void filter_4xBRZ (uint8 *, int, uint8 *, int, int, int);

#endif
